package com.ruoyi.system.mapper;

import com.ruoyi.system.domain.RmEpsTopologyManagement;

import java.util.List;

/**
 * 拓扑管理Mapper接口
 * 
 * @author gyt
 * @date 2025-08-12
 */
public interface RmEpsTopologyManagementMapper 
{
    /**
     * 查询拓扑管理
     * 
     * @param id 拓扑管理主键
     * @return 拓扑管理
     */
    public RmEpsTopologyManagement selectRmEpsTopologyManagementById(Long id);

    /**
     * 查询拓扑管理列表
     * 
     * @param rmEpsTopologyManagement 拓扑管理
     * @return 拓扑管理集合
     */
    public List<RmEpsTopologyManagement> selectRmEpsTopologyManagementList(RmEpsTopologyManagement rmEpsTopologyManagement);

    /**
     * 新增拓扑管理
     * 
     * @param rmEpsTopologyManagement 拓扑管理
     * @return 结果
     */
    public int insertRmEpsTopologyManagement(RmEpsTopologyManagement rmEpsTopologyManagement);

    /**
     * 修改拓扑管理
     * 
     * @param rmEpsTopologyManagement 拓扑管理
     * @return 结果
     */
    public int updateRmEpsTopologyManagement(RmEpsTopologyManagement rmEpsTopologyManagement);

    /**
     * 删除拓扑管理
     * 
     * @param id 拓扑管理主键
     * @return 结果
     */
    public int deleteRmEpsTopologyManagementById(Long id);

    /**
     * 批量删除拓扑管理
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteRmEpsTopologyManagementByIds(Long[] ids);

    int updateRmEpsTopologyManagementByServerSn(RmEpsTopologyManagement rmEpsTopologyManagement);

    int updateRmEpsTopologyManagementBySwitchSn(RmEpsTopologyManagement rmEpsTopologyManagement);
}
